/* pkcs11-private-key.c generated by valac 0.22.1, the Vala compiler
 * generated from pkcs11-private-key.vala, do not modify */

/*
 * Seahorse
 *
 * Copyright (C) 2008 Stefan Walter
 * Copyright (C) 2011 Collabora Ltd.
 * Copyright (C) 2013 Red Hat Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#include <glib.h>
#include <glib-object.h>
#include "seahorse-pkcs11.h"
#include <gck/gck.h>
#include <gio/gio.h>
#include "seahorse-common.h"
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <p11-kit/pkcs11.h>
#include <gcr/gcr-base.h>
#include <glib/gi18n-lib.h>

#define __vala_GckAttributes_free0(var) ((var == NULL) ? NULL : (var = (_vala_GckAttributes_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GckBuilder_free0(var) ((var == NULL) ? NULL : (var = (_vala_GckBuilder_free (var), NULL)))

#define SEAHORSE_PKCS11_TYPE_KEY_DELETER (seahorse_pkcs11_key_deleter_get_type ())
#define SEAHORSE_PKCS11_KEY_DELETER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_PKCS11_TYPE_KEY_DELETER, SeahorsePkcs11KeyDeleter))
#define SEAHORSE_PKCS11_KEY_DELETER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_PKCS11_TYPE_KEY_DELETER, SeahorsePkcs11KeyDeleterClass))
#define SEAHORSE_PKCS11_IS_KEY_DELETER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_PKCS11_TYPE_KEY_DELETER))
#define SEAHORSE_PKCS11_IS_KEY_DELETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_PKCS11_TYPE_KEY_DELETER))
#define SEAHORSE_PKCS11_KEY_DELETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_PKCS11_TYPE_KEY_DELETER, SeahorsePkcs11KeyDeleterClass))

typedef struct _SeahorsePkcs11KeyDeleter SeahorsePkcs11KeyDeleter;
typedef struct _SeahorsePkcs11KeyDeleterClass SeahorsePkcs11KeyDeleterClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

struct _SeahorsePkcs11PrivateKeyPrivate {
	GWeakRef _token;
	GckAttributes* _attributes;
	GWeakRef _certificate;
	GIcon* _icon;
};


static gpointer seahorse_pkcs11_private_key_parent_class = NULL;
static GckObjectCacheIface* seahorse_pkcs11_private_key_gck_object_cache_parent_iface = NULL;
static SeahorseDeletableIface* seahorse_pkcs11_private_key_seahorse_deletable_parent_iface = NULL;
static SeahorseExportableIface* seahorse_pkcs11_private_key_seahorse_exportable_parent_iface = NULL;
static SeahorseViewableIface* seahorse_pkcs11_private_key_seahorse_viewable_parent_iface = NULL;

#define SEAHORSE_PKCS11_PRIVATE_KEY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SEAHORSE_PKCS11_TYPE_PRIVATE_KEY, SeahorsePkcs11PrivateKeyPrivate))
enum  {
	SEAHORSE_PKCS11_PRIVATE_KEY_DUMMY_PROPERTY,
	SEAHORSE_PKCS11_PRIVATE_KEY_PLACE,
	SEAHORSE_PKCS11_PRIVATE_KEY_OBJECT_FLAGS,
	SEAHORSE_PKCS11_PRIVATE_KEY_ACTIONS,
	SEAHORSE_PKCS11_PRIVATE_KEY_PARTNER,
	SEAHORSE_PKCS11_PRIVATE_KEY_LABEL,
	SEAHORSE_PKCS11_PRIVATE_KEY_MARKUP,
	SEAHORSE_PKCS11_PRIVATE_KEY_DESCRIPTION,
	SEAHORSE_PKCS11_PRIVATE_KEY_ICON,
	SEAHORSE_PKCS11_PRIVATE_KEY_ATTRIBUTES,
	SEAHORSE_PKCS11_PRIVATE_KEY_DELETABLE,
	SEAHORSE_PKCS11_PRIVATE_KEY_EXPORTABLE
};
static void _vala_GckAttributes_free (GckAttributes* self);
static void seahorse_pkcs11_private_key_real_fill (GckObjectCache* base, GckAttributes* attributes);
static void _vala_GckBuilder_free (GckBuilder* self);
static SeahorseDeleter* seahorse_pkcs11_private_key_real_create_deleter (SeahorseDeletable* base);
SeahorsePkcs11KeyDeleter* seahorse_pkcs11_key_deleter_new (GckObject* cert_or_key);
SeahorsePkcs11KeyDeleter* seahorse_pkcs11_key_deleter_construct (GType object_type, GckObject* cert_or_key);
GType seahorse_pkcs11_key_deleter_get_type (void) G_GNUC_CONST;
static GList* seahorse_pkcs11_private_key_real_create_exporters (SeahorseExportable* base, SeahorseExporterType type);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static GtkWindow* seahorse_pkcs11_private_key_real_create_viewer (SeahorseViewable* base, GtkWindow* parent);
static GckAttributes* _vala_GckAttributes_copy (GckAttributes* self);
static void seahorse_pkcs11_private_key_finalize (GObject* obj);
static void _vala_seahorse_pkcs11_private_key_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_seahorse_pkcs11_private_key_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static void _vala_GckAttributes_free (GckAttributes* self) {
#line 101 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_boxed_free (gck_attributes_get_type (), self);
#line 106 "pkcs11-private-key.c"
}


static void _vala_GckBuilder_free (GckBuilder* self) {
#line 105 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_boxed_free (gck_builder_get_type (), self);
#line 113 "pkcs11-private-key.c"
}


static void seahorse_pkcs11_private_key_real_fill (GckObjectCache* base, GckAttributes* attributes) {
	SeahorsePkcs11PrivateKey * self;
	GckBuilder* builder = NULL;
	GckBuilder* _tmp0_ = NULL;
	GckAttributes* _tmp1_ = NULL;
	GckBuilder* _tmp4_ = NULL;
	GckAttributes* _tmp5_ = NULL;
	GckBuilder* _tmp6_ = NULL;
	GckAttributes* _tmp7_ = NULL;
#line 105 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self = (SeahorsePkcs11PrivateKey*) base;
#line 105 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_if_fail (attributes != NULL);
#line 106 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = gck_builder_new (GCK_BUILDER_NONE);
#line 106 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	builder = _tmp0_;
#line 107 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp1_ = self->priv->_attributes;
#line 107 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	if (_tmp1_ != NULL) {
#line 138 "pkcs11-private-key.c"
		GckBuilder* _tmp2_ = NULL;
		GckAttributes* _tmp3_ = NULL;
#line 108 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp2_ = builder;
#line 108 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp3_ = self->priv->_attributes;
#line 108 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		gck_builder_add_all (_tmp2_, _tmp3_);
#line 147 "pkcs11-private-key.c"
	}
#line 109 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp4_ = builder;
#line 109 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp5_ = attributes;
#line 109 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	gck_builder_set_all (_tmp4_, _tmp5_);
#line 110 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp6_ = builder;
#line 110 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp7_ = gck_builder_steal (_tmp6_);
#line 110 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	__vala_GckAttributes_free0 (self->priv->_attributes);
#line 110 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self->priv->_attributes = _tmp7_;
#line 111 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_notify ((GObject*) self, "attributes");
#line 105 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	__vala_GckBuilder_free0 (builder);
#line 167 "pkcs11-private-key.c"
}


static SeahorseDeleter* seahorse_pkcs11_private_key_real_create_deleter (SeahorseDeletable* base) {
	SeahorsePkcs11PrivateKey * self;
	SeahorseDeleter* result = NULL;
	SeahorsePkcs11KeyDeleter* _tmp0_ = NULL;
#line 114 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self = (SeahorsePkcs11PrivateKey*) base;
#line 115 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = seahorse_pkcs11_key_deleter_new ((GckObject*) self);
#line 115 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = (SeahorseDeleter*) _tmp0_;
#line 115 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 183 "pkcs11-private-key.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 118 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 190 "pkcs11-private-key.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 118 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 118 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_list_free (self);
#line 199 "pkcs11-private-key.c"
}


static GList* seahorse_pkcs11_private_key_real_create_exporters (SeahorseExportable* base, SeahorseExporterType type) {
	SeahorsePkcs11PrivateKey * self;
	GList* result = NULL;
	GList* exporters = NULL;
#line 118 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self = (SeahorsePkcs11PrivateKey*) base;
#line 120 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	exporters = NULL;
#line 121 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = exporters;
#line 121 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 215 "pkcs11-private-key.c"
}


static GtkWindow* seahorse_pkcs11_private_key_real_create_viewer (SeahorseViewable* base, GtkWindow* parent) {
	SeahorsePkcs11PrivateKey * self;
	GtkWindow* result = NULL;
	SeahorsePkcs11Properties* viewer = NULL;
	GtkWindow* _tmp0_ = NULL;
	SeahorsePkcs11Properties* _tmp1_ = NULL;
#line 124 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self = (SeahorsePkcs11PrivateKey*) base;
#line 125 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = parent;
#line 125 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp1_ = seahorse_pkcs11_properties_new ((GckObject*) self, _tmp0_);
#line 125 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_ref_sink (_tmp1_);
#line 125 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	viewer = _tmp1_;
#line 126 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	gtk_widget_show ((GtkWidget*) viewer);
#line 127 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = (GtkWindow*) viewer;
#line 127 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 241 "pkcs11-private-key.c"
}


SeahorsePkcs11PrivateKey* seahorse_pkcs11_private_key_construct (GType object_type) {
	SeahorsePkcs11PrivateKey * self = NULL;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self = (SeahorsePkcs11PrivateKey*) g_object_new (object_type, NULL);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return self;
#line 251 "pkcs11-private-key.c"
}


SeahorsePkcs11PrivateKey* seahorse_pkcs11_private_key_new (void) {
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return seahorse_pkcs11_private_key_construct (SEAHORSE_PKCS11_TYPE_PRIVATE_KEY);
#line 258 "pkcs11-private-key.c"
}


SeahorsePkcs11Token* seahorse_pkcs11_private_key_get_place (SeahorsePkcs11PrivateKey* self) {
	SeahorsePkcs11Token* result;
	GObject* _tmp0_ = NULL;
#line 30 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 30 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = g_weak_ref_get (&self->priv->_token);
#line 30 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SEAHORSE_PKCS11_TYPE_TOKEN, SeahorsePkcs11Token);
#line 30 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 273 "pkcs11-private-key.c"
}


void seahorse_pkcs11_private_key_set_place (SeahorsePkcs11PrivateKey* self, SeahorsePkcs11Token* value) {
	SeahorsePkcs11Token* _tmp0_ = NULL;
#line 31 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_if_fail (self != NULL);
#line 31 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = value;
#line 31 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_weak_ref_set (&self->priv->_token, (GObject*) _tmp0_);
#line 31 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_notify ((GObject *) self, "place");
#line 287 "pkcs11-private-key.c"
}


SeahorseFlags seahorse_pkcs11_private_key_get_object_flags (SeahorsePkcs11PrivateKey* self) {
	SeahorseFlags result;
#line 35 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 35 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = SEAHORSE_FLAG_PERSONAL;
#line 35 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 299 "pkcs11-private-key.c"
}


GtkActionGroup* seahorse_pkcs11_private_key_get_actions (SeahorsePkcs11PrivateKey* self) {
	GtkActionGroup* result;
#line 39 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 39 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = NULL;
#line 39 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 311 "pkcs11-private-key.c"
}


SeahorsePkcs11Certificate* seahorse_pkcs11_private_key_get_partner (SeahorsePkcs11PrivateKey* self) {
	SeahorsePkcs11Certificate* result;
	GObject* _tmp0_ = NULL;
#line 43 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 43 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = g_weak_ref_get (&self->priv->_certificate);
#line 43 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SEAHORSE_PKCS11_TYPE_CERTIFICATE, SeahorsePkcs11Certificate);
#line 43 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 326 "pkcs11-private-key.c"
}


void seahorse_pkcs11_private_key_set_partner (SeahorsePkcs11PrivateKey* self, SeahorsePkcs11Certificate* value) {
	SeahorsePkcs11Certificate* _tmp0_ = NULL;
#line 44 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_if_fail (self != NULL);
#line 45 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = value;
#line 45 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_weak_ref_set (&self->priv->_certificate, (GObject*) _tmp0_);
#line 46 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_notify ((GObject*) self, "partner");
#line 47 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_notify ((GObject*) self, "description");
#line 44 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_notify ((GObject *) self, "partner");
#line 344 "pkcs11-private-key.c"
}


gchar* seahorse_pkcs11_private_key_get_label (SeahorsePkcs11PrivateKey* self) {
	gchar* result;
	GckAttributes* _tmp0_ = NULL;
	SeahorsePkcs11Certificate* cert = NULL;
	SeahorsePkcs11Certificate* _tmp4_ = NULL;
	SeahorsePkcs11Certificate* _tmp5_ = NULL;
	SeahorsePkcs11Certificate* _tmp6_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
#line 52 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 53 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = self->priv->_attributes;
#line 53 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	if (_tmp0_ != NULL) {
#line 363 "pkcs11-private-key.c"
		gchar* label = NULL;
		GckAttributes* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
#line 55 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp1_ = self->priv->_attributes;
#line 55 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp3_ = gck_attributes_find_string (_tmp1_, CKA_LABEL, &_tmp2_);
#line 55 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_g_free0 (label);
#line 55 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		label = _tmp2_;
#line 55 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		if (_tmp3_) {
#line 56 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
			result = label;
#line 56 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
			return result;
#line 382 "pkcs11-private-key.c"
		}
#line 53 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_g_free0 (label);
#line 386 "pkcs11-private-key.c"
	}
#line 58 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp4_ = seahorse_pkcs11_private_key_get_partner (self);
#line 58 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp5_ = _tmp4_;
#line 58 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	cert = _tmp5_;
#line 59 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp6_ = cert;
#line 59 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	if (_tmp6_ != NULL) {
#line 398 "pkcs11-private-key.c"
		SeahorsePkcs11Certificate* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 60 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp7_ = cert;
#line 60 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_object_get ((GcrCertificate*) _tmp7_, "label", &_tmp8_, NULL);
#line 60 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp9_ = _tmp8_;
#line 60 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		result = _tmp9_;
#line 60 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_g_object_unref0 (cert);
#line 60 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		return result;
#line 414 "pkcs11-private-key.c"
	}
#line 61 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp10_ = _ ("Unnamed private key");
#line 61 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 61 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = _tmp11_;
#line 61 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_g_object_unref0 (cert);
#line 61 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 426 "pkcs11-private-key.c"
}


gchar* seahorse_pkcs11_private_key_get_markup (SeahorsePkcs11PrivateKey* self) {
	gchar* result;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
#line 66 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 66 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = seahorse_pkcs11_private_key_get_label (self);
#line 66 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp1_ = _tmp0_;
#line 66 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp2_ = _tmp1_;
#line 66 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp3_ = g_markup_escape_text (_tmp2_, (gssize) (-1));
#line 66 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp4_ = _tmp3_;
#line 66 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_g_free0 (_tmp2_);
#line 66 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = _tmp4_;
#line 66 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 455 "pkcs11-private-key.c"
}


const gchar* seahorse_pkcs11_private_key_get_description (SeahorsePkcs11PrivateKey* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 70 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 70 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = _ ("Private key");
#line 70 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = _tmp0_;
#line 70 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 470 "pkcs11-private-key.c"
}


GIcon* seahorse_pkcs11_private_key_get_icon (SeahorsePkcs11PrivateKey* self) {
	GIcon* result;
	GIcon* _tmp0_ = NULL;
	GIcon* _tmp2_ = NULL;
#line 74 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 75 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = self->priv->_icon;
#line 75 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	if (_tmp0_ == NULL) {
#line 484 "pkcs11-private-key.c"
		GThemedIcon* _tmp1_ = NULL;
#line 76 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp1_ = (GThemedIcon*) g_themed_icon_new (GCR_ICON_KEY);
#line 76 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_g_object_unref0 (self->priv->_icon);
#line 76 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		self->priv->_icon = (GIcon*) _tmp1_;
#line 492 "pkcs11-private-key.c"
	}
#line 77 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp2_ = self->priv->_icon;
#line 77 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = _tmp2_;
#line 77 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 500 "pkcs11-private-key.c"
}


static GckAttributes* _vala_GckAttributes_copy (GckAttributes* self) {
#line 82 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return g_boxed_copy (gck_attributes_get_type (), self);
#line 507 "pkcs11-private-key.c"
}


static gpointer __vala_GckAttributes_copy0 (gpointer self) {
#line 82 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return self ? _vala_GckAttributes_copy (self) : NULL;
#line 514 "pkcs11-private-key.c"
}


static GckAttributes* seahorse_pkcs11_private_key_real_get_attributes (GckObjectCache* base) {
	GckAttributes* result;
	SeahorsePkcs11PrivateKey* self;
	GckAttributes* _tmp0_ = NULL;
	GckAttributes* _tmp1_ = NULL;
#line 82 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self = (SeahorsePkcs11PrivateKey*) base;
#line 82 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = self->priv->_attributes;
#line 82 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp1_ = __vala_GckAttributes_copy0 (_tmp0_);
#line 82 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = _tmp1_;
#line 82 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 533 "pkcs11-private-key.c"
}


static void seahorse_pkcs11_private_key_real_set_attributes (GckObjectCache* base, GckAttributes* value) {
	SeahorsePkcs11PrivateKey* self;
	GckAttributes* _tmp0_ = NULL;
	GckAttributes* _tmp1_ = NULL;
#line 83 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self = (SeahorsePkcs11PrivateKey*) base;
#line 84 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = value;
#line 84 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp1_ = __vala_GckAttributes_copy0 (_tmp0_);
#line 84 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	__vala_GckAttributes_free0 (self->priv->_attributes);
#line 84 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self->priv->_attributes = _tmp1_;
#line 85 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_notify ((GObject*) self, "attributes");
#line 83 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_notify ((GObject *) self, "attributes");
#line 555 "pkcs11-private-key.c"
}


static gboolean seahorse_pkcs11_private_key_real_get_deletable (SeahorseDeletable* base) {
	gboolean result;
	SeahorsePkcs11PrivateKey* self;
	SeahorsePkcs11Token* token = NULL;
	SeahorsePkcs11Token* _tmp0_ = NULL;
	SeahorsePkcs11Token* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	SeahorsePkcs11Token* _tmp3_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 90 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self = (SeahorsePkcs11PrivateKey*) base;
#line 91 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp0_ = seahorse_pkcs11_private_key_get_place (self);
#line 91 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp1_ = _tmp0_;
#line 91 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	token = _tmp1_;
#line 92 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp3_ = token;
#line 92 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	if (_tmp3_ == NULL) {
#line 92 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp2_ = FALSE;
#line 582 "pkcs11-private-key.c"
	} else {
		SeahorsePkcs11Token* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
#line 92 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp4_ = token;
#line 92 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp5_ = seahorse_pkcs11_token_is_deletable (_tmp4_, (GckObject*) self);
#line 92 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		_tmp2_ = _tmp5_;
#line 592 "pkcs11-private-key.c"
	}
#line 92 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_tmp6_ = _tmp2_;
#line 92 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = _tmp6_;
#line 92 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_g_object_unref0 (token);
#line 92 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 602 "pkcs11-private-key.c"
}


static gboolean seahorse_pkcs11_private_key_real_get_exportable (SeahorseExportable* base) {
	gboolean result;
	SeahorsePkcs11PrivateKey* self;
#line 97 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self = (SeahorsePkcs11PrivateKey*) base;
#line 97 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	result = FALSE;
#line 97 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	return result;
#line 615 "pkcs11-private-key.c"
}


static void seahorse_pkcs11_private_key_class_init (SeahorsePkcs11PrivateKeyClass * klass) {
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	seahorse_pkcs11_private_key_parent_class = g_type_class_peek_parent (klass);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_type_class_add_private (klass, sizeof (SeahorsePkcs11PrivateKeyPrivate));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_seahorse_pkcs11_private_key_get_property;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_seahorse_pkcs11_private_key_set_property;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	G_OBJECT_CLASS (klass)->finalize = seahorse_pkcs11_private_key_finalize;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_PLACE, g_param_spec_object ("place", "place", "place", SEAHORSE_PKCS11_TYPE_TOKEN, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_OBJECT_FLAGS, g_param_spec_flags ("object-flags", "object-flags", "object-flags", SEAHORSE_TYPE_FLAGS, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_ACTIONS, g_param_spec_object ("actions", "actions", "actions", GTK_TYPE_ACTION_GROUP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_PARTNER, g_param_spec_object ("partner", "partner", "partner", SEAHORSE_PKCS11_TYPE_CERTIFICATE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_LABEL, g_param_spec_string ("label", "label", "label", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_MARKUP, g_param_spec_string ("markup", "markup", "markup", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_DESCRIPTION, g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_ICON, g_param_spec_object ("icon", "icon", "icon", G_TYPE_ICON, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_ATTRIBUTES, g_param_spec_boxed ("attributes", "attributes", "attributes", gck_attributes_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_DELETABLE, g_param_spec_boolean ("deletable", "deletable", "deletable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_PKCS11_PRIVATE_KEY_EXPORTABLE, g_param_spec_boolean ("exportable", "exportable", "exportable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 652 "pkcs11-private-key.c"
}


static void seahorse_pkcs11_private_key_gck_object_cache_interface_init (GckObjectCacheIface * iface) {
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	seahorse_pkcs11_private_key_gck_object_cache_parent_iface = g_type_interface_peek_parent (iface);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	iface->fill = (void (*)(GckObjectCache*, GckAttributes*)) seahorse_pkcs11_private_key_real_fill;
#line 661 "pkcs11-private-key.c"
}


static void seahorse_pkcs11_private_key_seahorse_deletable_interface_init (SeahorseDeletableIface * iface) {
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	seahorse_pkcs11_private_key_seahorse_deletable_parent_iface = g_type_interface_peek_parent (iface);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	iface->create_deleter = (SeahorseDeleter* (*)(SeahorseDeletable*)) seahorse_pkcs11_private_key_real_create_deleter;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	iface->get_deletable = seahorse_pkcs11_private_key_real_get_deletable;
#line 672 "pkcs11-private-key.c"
}


static void seahorse_pkcs11_private_key_seahorse_exportable_interface_init (SeahorseExportableIface * iface) {
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	seahorse_pkcs11_private_key_seahorse_exportable_parent_iface = g_type_interface_peek_parent (iface);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	iface->create_exporters = (GList* (*)(SeahorseExportable*, SeahorseExporterType)) seahorse_pkcs11_private_key_real_create_exporters;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	iface->get_exportable = seahorse_pkcs11_private_key_real_get_exportable;
#line 683 "pkcs11-private-key.c"
}


static void seahorse_pkcs11_private_key_seahorse_viewable_interface_init (SeahorseViewableIface * iface) {
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	seahorse_pkcs11_private_key_seahorse_viewable_parent_iface = g_type_interface_peek_parent (iface);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	iface->create_viewer = (GtkWindow* (*)(SeahorseViewable*, GtkWindow*)) seahorse_pkcs11_private_key_real_create_viewer;
#line 692 "pkcs11-private-key.c"
}


static void seahorse_pkcs11_private_key_instance_init (SeahorsePkcs11PrivateKey * self) {
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self->priv = SEAHORSE_PKCS11_PRIVATE_KEY_GET_PRIVATE (self);
#line 699 "pkcs11-private-key.c"
}


static void seahorse_pkcs11_private_key_finalize (GObject* obj) {
	SeahorsePkcs11PrivateKey * self;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SEAHORSE_PKCS11_TYPE_PRIVATE_KEY, SeahorsePkcs11PrivateKey);
#line 100 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_weak_ref_clear (&self->priv->_token);
#line 101 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	__vala_GckAttributes_free0 (self->priv->_attributes);
#line 102 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	g_weak_ref_clear (&self->priv->_certificate);
#line 103 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	_g_object_unref0 (self->priv->_icon);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	G_OBJECT_CLASS (seahorse_pkcs11_private_key_parent_class)->finalize (obj);
#line 717 "pkcs11-private-key.c"
}


GType seahorse_pkcs11_private_key_get_type (void) {
	static volatile gsize seahorse_pkcs11_private_key_type_id__volatile = 0;
	if (g_once_init_enter (&seahorse_pkcs11_private_key_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SeahorsePkcs11PrivateKeyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) seahorse_pkcs11_private_key_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SeahorsePkcs11PrivateKey), 0, (GInstanceInitFunc) seahorse_pkcs11_private_key_instance_init, NULL };
		static const GInterfaceInfo gck_object_cache_info = { (GInterfaceInitFunc) seahorse_pkcs11_private_key_gck_object_cache_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo seahorse_deletable_info = { (GInterfaceInitFunc) seahorse_pkcs11_private_key_seahorse_deletable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo seahorse_exportable_info = { (GInterfaceInitFunc) seahorse_pkcs11_private_key_seahorse_exportable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo seahorse_viewable_info = { (GInterfaceInitFunc) seahorse_pkcs11_private_key_seahorse_viewable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType seahorse_pkcs11_private_key_type_id;
		seahorse_pkcs11_private_key_type_id = g_type_register_static (gck_object_get_type (), "SeahorsePkcs11PrivateKey", &g_define_type_info, 0);
		g_type_add_interface_static (seahorse_pkcs11_private_key_type_id, gck_object_cache_get_type (), &gck_object_cache_info);
		g_type_add_interface_static (seahorse_pkcs11_private_key_type_id, SEAHORSE_TYPE_DELETABLE, &seahorse_deletable_info);
		g_type_add_interface_static (seahorse_pkcs11_private_key_type_id, SEAHORSE_TYPE_EXPORTABLE, &seahorse_exportable_info);
		g_type_add_interface_static (seahorse_pkcs11_private_key_type_id, SEAHORSE_TYPE_VIEWABLE, &seahorse_viewable_info);
		g_once_init_leave (&seahorse_pkcs11_private_key_type_id__volatile, seahorse_pkcs11_private_key_type_id);
	}
	return seahorse_pkcs11_private_key_type_id__volatile;
}


static void _vala_seahorse_pkcs11_private_key_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	SeahorsePkcs11PrivateKey * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SEAHORSE_PKCS11_TYPE_PRIVATE_KEY, SeahorsePkcs11PrivateKey);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	switch (property_id) {
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_PLACE:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_take_object (value, seahorse_pkcs11_private_key_get_place (self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_OBJECT_FLAGS:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_set_flags (value, seahorse_pkcs11_private_key_get_object_flags (self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_ACTIONS:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_set_object (value, seahorse_pkcs11_private_key_get_actions (self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_PARTNER:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_take_object (value, seahorse_pkcs11_private_key_get_partner (self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_LABEL:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_take_string (value, seahorse_pkcs11_private_key_get_label (self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_MARKUP:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_take_string (value, seahorse_pkcs11_private_key_get_markup (self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_DESCRIPTION:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_set_string (value, seahorse_pkcs11_private_key_get_description (self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_ICON:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_set_object (value, seahorse_pkcs11_private_key_get_icon (self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_ATTRIBUTES:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_take_boxed (value, seahorse_pkcs11_private_key_real_get_attributes ((GckObjectCache*) self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_DELETABLE:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_set_boolean (value, seahorse_deletable_get_deletable ((SeahorseDeletable*) self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_EXPORTABLE:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		g_value_set_boolean (value, seahorse_exportable_get_exportable ((SeahorseExportable*) self));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 812 "pkcs11-private-key.c"
		default:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 818 "pkcs11-private-key.c"
	}
}


static void _vala_seahorse_pkcs11_private_key_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	SeahorsePkcs11PrivateKey * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SEAHORSE_PKCS11_TYPE_PRIVATE_KEY, SeahorsePkcs11PrivateKey);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
	switch (property_id) {
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_PLACE:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		seahorse_pkcs11_private_key_set_place (self, g_value_get_object (value));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_PARTNER:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		seahorse_pkcs11_private_key_set_partner (self, g_value_get_object (value));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		case SEAHORSE_PKCS11_PRIVATE_KEY_ATTRIBUTES:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		seahorse_pkcs11_private_key_real_set_attributes ((GckObjectCache*) self, g_value_get_boxed (value));
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 846 "pkcs11-private-key.c"
		default:
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 27 "/data/src/seahorse/pkcs11/pkcs11-private-key.vala"
		break;
#line 852 "pkcs11-private-key.c"
	}
}



